==> programy-1.8.0.tar.gz: programy-1.8.0/programy/parser/template/nodes/word.py <==
"""
Copyright (c) 2016-17 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""

import logging

from programy.parser.template.nodes.base import TemplateNode
from programy.utils.text.text import TextUtils

class TemplateWordNode(TemplateNode):

    def __init__(self, word):
        TemplateNode.__init__(self)
        self._word = word

    @property
    def word(self):
        return self._word

    @word.setter
    def word(self, word):
        self._word = word

    def resolve(self, bot, clientid):
        if logging.getLogger().isEnabledFor(logging.DEBUG):
            logging.debug("[%s] resolved to [%s]", self.to_string(), self.word)
        if self.word is not None:
            return self.word
        return ""

    def to_string(self):
        return "[WORD]" + self.word

    def to_xml(self, bot, clientid):
        return TextUtils.html_escape(self.word)

==> programy-3.0.2.tar.gz: programy-3.0.2/programy/parser/template/nodes/word.py <==
"""
Copyright (c) 2016-2018 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""

from programy.utils.logging.ylogger import YLogger

from programy.parser.template.nodes.base import TemplateNode
from programy.utils.text.text import TextUtils

class TemplateWordNode(TemplateNode):

    def __init__(self, word):
        TemplateNode.__init__(self)
        self._word = word

    @property
    def word(self):
        return self._word

    @word.setter
    def word(self, word):
        self._word = word

    def resolve(self, client_context):
        YLogger.debug(client_context, "[%s] resolved to [%s]", self.to_string(), self.word)
        if self.word is not None:
            return self.word
        return ""

    def to_string(self):
        return "[WORD]" + self.word

    def to_xml(self, client_context):
        return TextUtils.html_escape(self.word)
